quote

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: GPL-3.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var QuoteCommand = discord.SlashCommandCreate{
	Name: "quote",
	NameLocalizations: map[discord.Locale]string{
		discord.LocaleNorwegian: "siter",
	},
	Description: "Quote a message from a channel, using a message link.",
	DescriptionLocalizations: map[discord.Locale]string{
		discord.LocaleNorwegian: "Lag et sitat av ei melding.",
	},

	Contexts:                 []discord.InteractionContextType{discord.InteractionContextTypeGuild},
	DefaultMemberPermissions: omit.NewPtr(discord.PermissionSendMessages),

	Options: []discord.ApplicationCommandOption{
		discord.ApplicationCommandOptionString{
			Name: "link",
			NameLocalizations: map[discord.Locale]string{
				discord.LocaleNorwegian: "lenke",
			},
			Description: "Link to the message you want to quote.",
			DescriptionLocalizations: map[discord.Locale]string{
				discord.LocaleNorwegian: "Lenke til meldinga du vil sitere.",
			},
			Required: true,
		},
		discord.ApplicationCommandOptionBool{
			Name: "show-reply-to",
			NameLocalizations: map[discord.Locale]string{
				discord.LocaleNorwegian: "vis-svar-til",
			},
			Description: "Whether to show and link the message that the quoted message replies to. (Default: true)",
			DescriptionLocalizations: map[discord.Locale]string{
				discord.LocaleNorwegian: "Om du vil vise og lenke til meldingen som sitatet er et svar til. (Standard er å vise)",
			},
			Required: false,
		},
	},
}

Functions

func CreateMessageQuoteEmbed

func CreateMessageQuoteEmbed(client *bot.Client, message *discord.Message, showReferenced bool) discord.Embed

func QuoteHandler

func QuoteHandler(e *handler.CommandEvent) error

Types

This section is empty.

Jump to